@@ -7,4 +7,6 @@ from .parse import parse_int, parse_float
 from .ostools import *
 from .sysargs import args_to_dictionary
 from . import colorama_ext
-from .progression_bar import progress_bar
\ No newline at end of file
+from .progression_bar import progress_bar
+from .log import log
+from .generator import random_string
\ No newline at end of file
